@@ -1,7 +1,44 @@
-require 'csv'
-require 'puppet/util/inifile'
+# Add openstacklib code to $LOAD_PATH so that we can load this during
+# standalone compiles without error.
+File.expand_path('../../../../openstacklib/lib', File.dirname(__FILE__)).tap { |dir| $LOAD_PATH.unshift(dir) unless $LOAD_PATH.include?(dir) }
 
-class Puppet::Provider::Neutron < Puppet::Provider
+require 'puppet/util/inifile'
+require 'puppet/provider/openstack'
+require 'puppet/provider/openstack/auth'
+require 'puppet/provider/openstack/credentials'
+require 'csv'
+
+class Puppet::Provider::Neutron < Puppet::Provider::Openstack
+
+  extend Puppet::Provider::Openstack::Auth
+
+  initvars
+  commands :neutron => 'neutron'
+
+  def self.request(service, action, properties=nil)
+    begin
+      super
+    rescue Puppet::Error::OpenstackAuthInputError => error
+      neutron_request(service, action, error, properties)
+    end
+  end
+
+  def self.neutron_request(service, action, error, properties=nil)
+    properties ||= []
+    @credentials.username = neutron_credentials['username']
+    @credentials.password = neutron_credentials['password']
+    @credentials.project_name = neutron_credentials['project_name']
+    @credentials.auth_url = auth_endpoint
+    if @credentials.version == '3'
+      @credentials.user_domain_name = neutron_credentials['user_domain_name']
+      @credentials.project_domain_name = neutron_credentials['project_domain_name']
+    end
+    if neutron_credentials['region_name']
+      @credentials.region_name = neutron_credentials['region_name']
+    end
+    raise error unless @credentials.set?
+    Puppet::Provider::Openstack.request(service, action, properties, @credentials)
+  end
 
   def self.conf_filename
     '/etc/neutron/neutron.conf'
@@ -21,43 +58,6 @@ class Puppet::Provider::Neutron < Puppet::Provider
     end
   end
 
-  def self.neutron_credentials
-    @neutron_credentials ||= get_neutron_credentials
-  end
-
-  def self.get_neutron_credentials
-    deprecated_auth_keys = ['admin_tenant_name', 'admin_user', 'admin_password', 'identity_uri']
-    auth_keys = ['project_name', 'username', 'password', 'auth_url']
-    conf = neutron_conf
-    if conf and conf['keystone_authtoken'] and
-        !conf['keystone_authtoken']['password'].nil? and
-        auth_keys.all?{|k| !conf['keystone_authtoken'][k].nil?}
-      creds = Hash[ auth_keys.map \
-                   { |k| [k, conf['keystone_authtoken'][k].strip] } ]
-      if !conf['keystone_authtoken']['region_name'].nil?
-        creds['region_name'] = conf['keystone_authtoken']['region_name'].strip
-      end
-      return creds
-    elsif conf and conf['keystone_authtoken'] and
-        !conf['keystone_authtoken']['admin_password'].nil? and
-        deprecated_auth_keys.all?{|k| !conf['keystone_authtoken'][k].nil?}
-      creds = Hash[ deprecated_auth_keys.map \
-                   { |k| [k, conf['keystone_authtoken'][k].strip] } ]
-      if conf['DEFAULT'] and !conf['DEFAULT']['nova_region_name'].nil?
-        creds['nova_region_name'] = conf['DEFAULT']['nova_region_name'].strip
-      end
-      return creds
-    else
-      raise(Puppet::Error, "File: #{conf_filename} does not contain all \
-required sections.  Neutron types will not work if neutron is not \
-correctly configured.")
-    end
-  end
-
-  def neutron_credentials
-    self.class.neutron_credentials
-  end
-
   def self.neutron_conf
     return @neutron_conf if @neutron_conf
     @neutron_conf = Puppet::Util::IniConfig::File.new
@@ -65,26 +65,61 @@ correctly configured.")
     @neutron_conf
   end
 
+  def self.neutron_credentials
+    @neutron_credentials ||= get_neutron_credentials
+  end
+
+  def neutron_credentials
+    self.class.neutron_credentials
+  end
+
+  def self.get_neutron_credentials
+    #needed keys for authentication
+    auth_keys = ['auth_uri', 'project_name', 'username', 'password']
+    conf = neutron_conf
+    if conf and conf['keystone_authtoken'] and
+        auth_keys.all?{|k| !conf['keystone_authtoken'][k].nil?}
+      creds = Hash[ auth_keys.map \
+                   { |k| [k, conf['keystone_authtoken'][k].strip] } ]
+      if conf['neutron'] and conf['neutron']['region_name']
+        creds['region_name'] = conf['neutron']['region_name'].strip
+      end
+      if !conf['keystone_authtoken']['project_domain_name'].nil?
+        creds['project_domain_name'] = conf['keystone_authtoken']['project_domain_name'].strip
+      else
+        creds['project_domain_name'] = 'Default'
+      end
+      if !conf['keystone_authtoken']['user_domain_name'].nil?
+        creds['user_domain_name'] = conf['keystone_authtoken']['user_domain_name'].strip
+      else
+        creds['user_domain_name'] = 'Default'
+      end
+      return creds
+    else
+      raise(Puppet::Error, "File: #{conf_filename} does not contain all " +
+            "required sections.  Neutron types will not work if neutron is not " +
+            "correctly configured.")
+    end
+  end
+
+  def self.get_auth_endpoint
+    q = neutron_credentials
+    "#{q['auth_uri']}"
+  end
+
+  def self.auth_endpoint
+    @auth_endpoint ||= get_auth_endpoint
+  end
+
   def self.auth_neutron(*args)
     q = neutron_credentials
-    if q.key?('admin_password')
-      authenv = {
-        :OS_AUTH_URL    => q['identity_uri'],
-        :OS_USERNAME    => q['admin_user'],
-        :OS_TENANT_NAME => q['admin_tenant_name'],
-        :OS_PASSWORD    => q['admin_password']
-      }
-    else
-      authenv = {
-        :OS_AUTH_URL     => q['auth_url'],
-        :OS_USERNAME     => q['username'],
-        :OS_PROJECT_NAME => q['project_name'],
-        :OS_PASSWORD     => q['password']
-      }
-    end
-    if q.key?('nova_region_name')
-      authenv[:OS_REGION_NAME] = q['nova_region_name']
-    elsif q.key?('region_name')
+    authenv = {
+      :OS_AUTH_URL     => self.auth_endpoint,
+      :OS_USERNAME     => q['username'],
+      :OS_PROJECT_NAME => q['project_name'],
+      :OS_PASSWORD     => q['password']
+    }
+    if q.key?('region_name')
       authenv[:OS_REGION_NAME] = q['region_name']
     end
     rv = nil
