@@ -310,7 +310,7 @@ describe 'neutron::agents::ml2::ovs' do
 
     context 'when enabling dpdk with manage vswitch is default' do
       let :pre_condition do
-        "class { 'vswitch::dpdk': core_list => '1,2', memory_channels => '1' }"
+        "class { 'vswitch::dpdk': host_core_list => '1,2', memory_channels => '1' }"
       end
       before :each do
         params.merge!(:enable_dpdk => true,
