@@ -52,9 +52,9 @@ describe 'neutron' do
       end
 
       it 'configures logging' do
-        is_expected.to contain_neutron_config('DEFAULT/log_file').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_neutron_config('DEFAULT/log_dir').with_value(params[:log_dir])
-        is_expected.to contain_neutron_config('DEFAULT/use_stderr').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_oslo__log('neutron_config').with(:log_file   => '<SERVICE DEFAULT>',
+                                                                :log_dir    => params[:log_dir],
+                                                                :use_stderr => '<SERVICE DEFAULT>')
       end
 
     end
@@ -311,13 +311,13 @@ describe 'neutron' do
       )
     end
 
-    it do
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('true')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('/path/to/ssl/ca/certs')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('/path/to/ssl/cert/file')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('/path/to/ssl/keyfile')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('TLSv1')
-    end
+    it { is_expected.to contain_oslo__messaging__rabbit('neutron_config').with(
+      :rabbit_use_ssl     => true,
+      :kombu_ssl_ca_certs => '/path/to/ssl/ca/certs',
+      :kombu_ssl_certfile => '/path/to/ssl/cert/file',
+      :kombu_ssl_keyfile  => '/path/to/ssl/keyfile',
+      :kombu_ssl_version  => 'TLSv1'
+    )}
   end
 
   shared_examples_for 'with SSL enabled without kombu' do
@@ -327,24 +327,16 @@ describe 'neutron' do
       )
     end
 
-    it do
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('true')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
-    end
+    it { is_expected.to contain_oslo__messaging__rabbit('neutron_config').with(
+      :rabbit_use_ssl     => true,
+    )}
   end
 
   shared_examples_for 'with SSL disabled' do
 
-    it do
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
-    end
+    it { is_expected.to contain_oslo__messaging__rabbit('neutron_config').with(
+      :rabbit_use_ssl     => '<SERVICE DEFAULT>',
+    )}
   end
 
   shared_examples_for 'with SSL and kombu wrongly configured' do
@@ -483,7 +475,6 @@ describe 'neutron' do
     context 'with default parameters' do
       before { params.merge!( :rpc_backend => 'amqp' ) }
 
-      it { is_expected.to contain_neutron_config('DEFAULT/rpc_backend').with_value('amqp') }
       it { is_expected.to contain_neutron_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_neutron_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_neutron_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>') }
@@ -514,7 +505,6 @@ describe 'neutron' do
         :amqp_password      => 'password',
       ) }
 
-      it { is_expected.to contain_neutron_config('DEFAULT/rpc_backend').with_value('amqp') }
       it { is_expected.to contain_neutron_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_neutron_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_neutron_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>') }
